aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorAnders Kalør <anders@kaloer.com>2019-08-12 20:47:22 +0200
committerDerek Kozel <derek.kozel@gmail.com>2019-08-29 10:08:45 +0100
commit822aedb5b8934549a10b70dc602a178f9765eef0 (patch)
treeb715f99866f00d9058604698b2427147dcaaade5
parentMake Id visible in Tab_widget (diff)
downloadgnuradio-822aedb5b8934549a10b70dc602a178f9765eef0.tar.xz
gnuradio-822aedb5b8934549a10b70dc602a178f9765eef0.zip
Improve GRC YAML template
-rw-r--r--gr-utils/python/modtool/templates/templates.py32
1 files changed, 17 insertions, 15 deletions
diff --git a/gr-utils/python/modtool/templates/templates.py b/gr-utils/python/modtool/templates/templates.py
index e89cf81ba..e6c1197dd 100644
--- a/gr-utils/python/modtool/templates/templates.py
+++ b/gr-utils/python/modtool/templates/templates.py
@@ -550,11 +550,11 @@ templates:
imports: import ${modname}
make: ${modname}.${blockname}(${strip_arg_types_grc(arglist)})
-# Make one 'parameters' list entry for every Parameter you want settable from the GUI.
-# Sub-entries of dictionary:
+# Make one 'parameters' list entry for every parameter you want settable from the GUI.
+# Keys include:
# * id (makes the value accessible as \$keyname, e.g. in the make entry)
-# * label
-# * dtype
+# * label (label shown in the GUI)
+# * dtype (e.g. int, float, complex, byte, short, xxx_vector, ...)
parameters:
- id: ...
label: ...
@@ -563,27 +563,29 @@ parameters:
label: ...
dtype: ...
# Make one 'inputs' list entry per input. Sub-entries of dictionary:
# * label (an identifier for the GUI)
-# * domain
-# * dtype
-# * vlen
-# * optional (set to 1 for optional inputs)
+# * domain (optional - stream or message. Default is stream)
+# * dtype (e.g. int, float, complex, byte, short, xxx_vector, ...)
+# * vlen (optional - data stream vector length. Default is 1)
+# * optional (optional - set to 1 for optional inputs. Default is 0)
inputs:
- label: ...
domain: ...
dtype: ...
vlen: ...
+ optional: ...
-# Make one 'outputs' list entry per output. Sub-entries of dictionary:
-# * label (an identifier for the GUI)
-# * dtype
-# * vlen
-# * optional (set to 1 for optional inputs)
+outputs:
- label: ...
domain: ...
- dtype: ... #!-- e.g. int, float, complex, byte, short, xxx_vector, ...--
+ dtype: ...
+ vlen: ...
+ optional: ...
+# 'file_format' specifies the version of the GRC yml format used in the file
+# and should usually not be changed.
file_format: 1
'''
@@ -563,27 +563,29 @@ parameters:
label: ...
dtype: ...
-# Make one 'inputs' list entry per input. Sub-entries of dictionary:
+# Make one 'inputs' list entry per input and one 'outputs' list entry per output.
+# Keys include:
# * label (an identifier for the GUI)